@@ -362,14 +362,14 @@ class Storage(Asset):
         if sep_needed:
             mapping['time_step'] = np.hstack((self.timegrid.restricted.I, self.timegrid.restricted.I))
             mapping['var_name']  = np.nan # name variables for use e.g. in RI
-            mapping.loc[0:n,'var_name']      = 'disp_in'
-            mapping.loc[n:2*n,'var_name']    = 'disp_out'
+            mapping['var_name'].iloc[0:n] = 'disp_in'
+            mapping['var_name'].iloc[n:] = 'disp_out'
             if len(self.nodes)==1:
                 mapping['node']      = self.nodes[0].name
             else: # separate nodes in / out.
                 mapping['node']  = np.nan
-                mapping.loc[0:n,'node']      = self.nodes[0].name
-                mapping.loc[n:2*n,'node']    = self.nodes[1].name
+                mapping['node'].iloc[0:n]      = self.nodes[0].name
+                mapping['node'].iloc[n:2*n]    = self.nodes[1].name
         else:
             mapping['time_step'] = self.timegrid.restricted.I
             mapping['node']      = self.nodes[0].name
@@ -595,8 +595,8 @@ class SimpleContract(Asset):
             # infos:             'asset', 'node', 'type' 
             mapping['time_step'] = np.hstack((I, I))
             mapping['var_name']  = np.nan # name variables for use e.g. in RI
-            mapping.loc[0:T,'var_name']      = 'disp_in'
-            mapping.loc[T:2*T,'var_name']    = 'disp_out'
+            mapping['var_name'].iloc[0:T] = 'disp_in'
+            mapping['var_name'].iloc[T:] = 'disp_out'
 
         # shortcut if only costs required
         if costs_only: 
